@@ -162,6 +162,13 @@ if [[ "${CONDA_BUILD_CROSS_COMPILATION}" == "1" ]]; then
   echo "ac_cv_file__dev_ptc=yes"        >> config.site
   echo "ac_cv_pthread=yes"              >> config.site
   echo "ac_cv_little_endian_double=yes" >> config.site
+  if [[ ${target_platform} == osx-arm64 ]]; then
+      echo "ac_cv_aligned_required=no" >> config.site
+      echo "ac_cv_file__dev_ptc=no" >> config.site
+      echo "ac_cv_pthread_is_default=yes" >> config.site
+      echo "ac_cv_working_tzset=yes" >> config.site
+      echo "ac_cv_pthread_system_supported=yes" >> config.site
+  fi
   export CONFIG_SITE=${PWD}/config.site
   # This is needed for libffi:
   export PKG_CONFIG_PATH=${PREFIX}/lib/pkgconfig
@@ -412,7 +419,7 @@ pushd "${PREFIX}"/lib/python${VER}
   # So we can see if anything has significantly diverged by looking in a built package.
   cp ${recorded_name} ${recorded_name}.orig
   mv ${recorded_name} ${our_compilers_name}
-  PY_ARCH=${HOST%-conda*}
+  PY_ARCH=$(echo ${HOST} | cut -d- -f1)
   # Copy all "${RECIPE_DIR}"/sysconfigdata/*.py. This is to support cross-compilation. They will be
   # from the previous build unfortunately so care must be taken at version bumps and flag changes.
   SRC_SYSCONFIGS=$(find "${RECIPE_DIR}"/sysconfigdata -name '*sysconfigdata*.py')
@@ -424,6 +431,7 @@ pushd "${PREFIX}"/lib/python${VER}
                                -e "s|@PYVERNODOTS@|${VERNODOTS}|g" \
                                -e "s|@PYVER@|${VER}|g" \
                                -e "s|@PYVERFULL@|${VERFULL}|g" \
+                               -e "s|@MACOSX_DEPLOYMENT_TARGET@|${MACOSX_DEPLOYMENT_TARGET:-10.9}|g" \
                                -e "s|@TCLTK_VER@|${TCLTK_VER}|g" > ${DST_SYSCONFIG}
   done
   if [[ ${HOST} =~ .*darwin.* ]]; then
